#
# spec file for package yubikey-personalization-gui
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yubikey-personalization-gui
Version:        3.1.24
Release:        2.2
Summary:        GUI for Yubikey personalization
License:        BSD-2-Clause
Group:          Productivity/Networking/Security
Url:            https://developers.yubico.com/
Source0:        https://developers.yubico.com/yubikey-personalization-gui/Releases/%{name}-%{version}.tar.gz
Source1:        https://developers.yubico.com/yubikey-personalization-gui/Releases/%{name}-%{version}.tar.gz.sig
BuildRequires:  desktop-file-utils
BuildRequires:  libykpers-devel => 1.14
BuildRequires:  libyubikey-devel => 1.12
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       ykpers >= 1.14

%description
The YubiKey Personalization Tool is a Qt based Cross-Platform utility
designed to facilitate re-configuration of YubiKeys on Windows, Linux
and MAC platforms. The tool provides a same simple step-by-step
approach to make configuration of YubiKeys easy to follow and
understand, while still being powerful enough to exploit all
functionality both of the YubiKey 1 and YubiKey 2 generation of
keys. The tool provides the same functionality and user interface on
Windows, Linux and MAC platforms.

The Cross-Platform YubiKey Personalization Tool provides the following
main functions:

	* Programming the YubiKey in "Yubico OTP" mode
	* Programming the YubiKey in "OATH-HOTP" mode
	* Programming the YubiKey in "Static Password" mode
	* Programming the YubiKey in "Challenge-Response" mode
	* Programming the NDEF feature of the YubiKey NEO
	* Testing the challenge-response functionality of a YubiKey
	* Deleting the configuration of a YubiKey
	* Checking type and firmware version of the YubiKey

%prep
%setup -q 

%build
qmake-qt5 CONFIG+="nosilent c++11" QMAKE_CXXFLAGS="%optflags -fvisibility=hidden -fvisibility-inlines-hidden"
make %{?_smp_mflags} 

%install
install -D -p -m 0755 build/release/%{name} %{buildroot}%{_bindir}/%{name}
install -D -p -m 0644 resources/lin/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
mkdir -p %{buildroot}/%{_datadir}/pixmaps
install -p -m 0644 resources/lin/%{name}.xpm %{buildroot}/%{_datadir}/pixmaps/
%suse_update_desktop_file -i %{name} System Security

%files
%defattr(-,root,root)
%doc NEWS README COPYING ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm
%{_mandir}/man1/%{name}.1*

%changelog
* Thu Jan  7 2016 t.gruner@katodev.de
- Version 3.1.24 (released 2016-01-04)
  - Fix a bug when doing consecutive programming that reset id to 0.
  - Fix a case where the image on an old key might be shown momentarily.
  - Updated icons and images.
  - Updated mac and windows builds to qt 5.5.
* Thu Oct  1 2015 t.gruner@katodev.de
- Version 3.1.23 (released 2015-10-01)
  - Fix a bug that caused a crash on selecting keyboard layout.
* Wed Sep 30 2015 t.gruner@katodev.de
- Version 3.1.22 (released 2015-09-25)
  - Fix so version detection works correctly for versions with more than one digit.
  - Add german keyboard layout.
  - Fixup neo-n picture
- fixes #56 - make sure scanedit is initialized
  - ------------------------------------------------------------------
* Tue Jun  2 2015 t.gruner@katodev.de
- Version 3.1.21 (released 2015-05-29)
  - Fix a bug where decode functions where given src length instead of result.
  - Fix an issue where test cases where installed by default.
  - Update pictures.
* Tue May  5 2015 crrodriguez@opensuse.org
- Version 3.1.20
  * Some new pictures.
  * Add some simplistic unit tests.
  * Fix bug with translation of | in scancode to text.
* Mon May  4 2015 crrodriguez@opensuse.org
- Testing of previous change, reveals this package
  can't work without ykpers main package, add requires.
* Thu Apr 30 2015 crrodriguez@opensuse.org
- Build againt QT5.
- Respect optflags
* Mon Mar 16 2015 t.gruner@katodev.de
- Version 3.1.19 (released 2015-03-13)
  - Remove build timestamp.
  - Add picture of Neo-N
* Tue Dec  9 2014 t.gruner@katodev.de
- Version 3.1.18 (released 2014-11-28)
  - Image and correct features for plus.
* Wed Nov  5 2014 t.gruner@katodev.de
- Version 3.1.17 (released 2014-10-30)
  - Fixup the Yubico logformat so accesscode is padded out with 0
  - Make texts translatable.
  - Include the accessibility plugin in bundles.
  - Show U2F as a feature.
  - Switch the mac bundle to qt5.
* Tue Sep 16 2014 t.gruner@katodev.de
- Version 3.1.16 (released 2014-09-16)
  - Fix bug where no random numbers where generated on windows.
- Version 3.1.15 (released 2014-09-11)
  - Add logging output format PSKC.
  - Force selection of keyboard layout before programing scancode mode.
  - Text changes.
  - New picture for YubiKey 3.3.
* Tue Jul 22 2014 t.gruner@katodev.de
- Initial version packaged - 3.1.14
